<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Storage;

class ArchivoReporteController extends Controller
{
    public function index()
    {
        $files = DB::table('archivos_reportes')
            ->orderBy('year', 'desc')
            ->orderBy('month', 'desc')
            ->get()
            ->groupBy(['year', 'month']);
        return view('inventario.archivo_reporte', compact('files'));
    }

    public function upload(Request $request)
    {
        try {
            $request->validate([
                'files.*' => 'required|file|mimes:xlsx,xls',
                'year' => 'required|integer',
                'month' => 'required|integer|between:1,12',
            ]);

            // Crear la carpeta si no existe
            $folderPath = "public/{$request->year}/{$request->month}";
            if (!Storage::exists($folderPath)) {
                Storage::makeDirectory($folderPath);
            }

            // Procesar cada archivo
            foreach ($request->file('files') as $file) {
                $filePath = $file->storeAs($folderPath, $file->getClientOriginalName());
                $filePathFromStorage = str_replace('public/', 'storage/', $filePath);

                // Insertar en la base de datos
                DB::table('archivos_reportes')->insert([
                    'file_name' => $file->getClientOriginalName(),
                    'file_path' => $filePathFromStorage,
                    'year' => $request->year,
                    'month' => $request->month,
                ]);
            }

            return redirect()->route('files.index')->with('success', 'Archivos cargados exitosamente.');
        } catch (\Throwable $th) {
            dd($th->getMessage() . ' ' . $th->getLine());
        }
    }


    public function delete($id)
    {
        $file = DB::table('archivos_reportes')->find($id);
        if ($file) {
            Storage::delete(str_replace('storage/', 'public/', $file->file_path));
            DB::table('archivos_reportes')->where('id', $id)->delete();
        }
        return redirect()->route('files.index')->with('success', 'Archivo eliminado.');
    }

    public function replace(Request $request, $id)
    {
        $request->validate([
            'file' => 'required|file|mimes:xlsx',
        ]);

        $file = DB::table('archivos_reportes')->find($id);
        if ($file) {
            Storage::delete(str_replace('storage/', 'public/', $file->file_path));
            $filePath = $request->file('file')->storeAs("public/{$file->year}/{$file->month}", $request->file('file')->getClientOriginalName());
            // Cambiar public/ por storage/ en la ruta de almacenamiento
            $filePathFromStorage = str_replace('public/', 'storage/', $filePath);
            DB::table('archivos_reportes')->where('id', $id)->update([
                'file_name' => $request->file('file')->getClientOriginalName(),
                'file_path' => $filePathFromStorage,
            ]);
        }

        return redirect()->route('files.index')->with('success', 'Archivo reemplazado.');
    }
}
