@extends('layouts.app')

@section('content')
@extends('inventario.menu')
<link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

<div class="container my-4">
    <div class="row ">
        <div class="col-md-12">
            <h2>Reportes Inventario</h2>
        </div>
    </div>

    <hr>


    @if(Auth::user()->id != 7 || Auth::user()->id != 9)
    <div>
        <div class="row ">
            <div class="col-md-12">
                <h3>Cargar Archivos</h3>
            </div>
        </div>
        {{-- Formulario de carga --}}
        <form action="{{ route('files.upload') }}" method="POST" enctype="multipart/form-data">
            @csrf
            <div class="mb-3">
                <label for="files" class="form-label">Seleccionar Archivos:</label>
                <input type="file" name="files[]" id="files" multiple class="form-control" required>
            </div>
            <div class="row my-2">
                <div class="col-md-6">
                    <label for="year" class="form-label">Año:</label>
                    <select name="year" id="year" class="form-select">
                        @foreach (range(date('Y'), date('Y') - 4) as $year)
                        <option value="{{ $year }}">{{ $year }}</option>
                        @endforeach
                    </select>
                </div>
                <div class="col-md-6">
                    <label for="month" class="form-label">Mes:</label>
                    <select name="month" id="month" class="form-select">
                        @foreach (range(1, 12) as $month)
                        <option value="{{ $month }}"><span
                                class="text-capitalize">{{ \Carbon\Carbon::create(null, $month)->locale('es')->translatedFormat('F') }}</span>
                        </option>
                        @endforeach
                    </select>
                </div>
            </div>
            <button type="submit" class="btn btn-primary my-2">Cargar Archivos</button>
        </form>
    </div>
    @endif

    <div class="row mt-5">
        <hr>
        <div class="col-md-12">
            <h4>Historial de Archivos Cargados</h4>
        </div>
    </div>


    {{-- Archivos cargados --}}
    @foreach ($files as $year => $months)
    <div class="accordion mb-3" id="accordion-{{ $year }}">
        <div class="accordion-item">
            <h2 class="accordion-header" id="heading-{{ $year }}">
                <button class="accordion-button collapsed" type="button" data-bs-toggle="collapse"
                    data-bs-target="#collapse-{{ $year }}" aria-expanded="false"
                    aria-controls="collapse-{{ $year }}">
                    {{ $year }}
                </button>
            </h2>
            <div id="collapse-{{ $year }}" class="accordion-collapse collapse"
                aria-labelledby="heading-{{ $year }}" data-bs-parent="#accordion-{{ $year }}">
                <div class="accordion-body">
                    <div class="accordion" id="accordion-months-{{ $year }}">
                        @foreach ($months as $month => $files)
                        <div class="accordion-item">
                            <h2 class="accordion-header"
                                id="heading-month-{{ $year }}-{{ $month }}">
                                <button class="accordion-button collapsed" type="button"
                                    data-bs-toggle="collapse"
                                    data-bs-target="#collapse-month-{{ $year }}-{{ $month }}"
                                    aria-expanded="false"
                                    aria-controls="collapse-month-{{ $year }}-{{ $month }}">
                                    {{ \Carbon\Carbon::create(null, $month)->locale('es')->translatedFormat('F') }}
                                </button>
                            </h2>
                            <div id="collapse-month-{{ $year }}-{{ $month }}"
                                class="accordion-collapse collapse"
                                aria-labelledby="heading-month-{{ $year }}-{{ $month }}"
                                data-bs-parent="#accordion-months-{{ $year }}">
                                <div class="accordion-body">
                                    <ul>
                                        @foreach ($files as $file)
                                        <li class="my-2">
                                            <span class="mx-5">{{ $file->file_name }}</span>

                                            {{-- Botón para descargar --}}
                                            <a href="{{ url($file->file_path) }}"
                                                class="btn btn-success btn-sm">
                                                Descargar
                                            </a>

                                            {{-- Botón para eliminar --}}
                                            {{-- <form action="{{ route('files.delete', $file->id) }}"
                                                method="POST" style="display:inline-block;">
                                                @csrf
                                                @method('DELETE')
                                                <button type="submit"
                                                    class="btn btn-danger btn-sm">Eliminar</button>
                                            </form> --}}

                                            {{-- Botón para abrir el modal de reemplazo --}}
                                            <button type="button" class="btn btn-warning btn-sm"
                                                data-bs-toggle="modal"
                                                data-bs-target="#replaceModal-{{ $file->id }}">
                                                Reemplazar
                                            </button>

                                            {{-- Modal para reemplazar archivo --}}
                                            <div class="modal fade" id="replaceModal-{{ $file->id }}"
                                                tabindex="-1"
                                                aria-labelledby="replaceModalLabel-{{ $file->id }}"
                                                aria-hidden="true">
                                                <div class="modal-dialog">
                                                    <div class="modal-content">
                                                        <div class="modal-header">
                                                            <h5 class="modal-title"
                                                                id="replaceModalLabel-{{ $file->id }}">
                                                                Reemplazar archivo: {{ $file->file_name }}
                                                            </h5>
                                                            <button type="button" class="btn-close"
                                                                data-bs-dismiss="modal"
                                                                aria-label="Close"></button>
                                                        </div>
                                                        <div class="modal-body">
                                                            <form
                                                                action="{{ route('files.replace', $file->id) }}"
                                                                method="POST"
                                                                enctype="multipart/form-data">
                                                                @csrf
                                                                <div class="mb-3">
                                                                    <label for="file-{{ $file->id }}"
                                                                        class="form-label">Seleccionar
                                                                        nuevo archivo:</label>
                                                                    <input type="file" name="file"
                                                                        id="file-{{ $file->id }}"
                                                                        class="form-control" required>
                                                                </div>
                                                                <button type="submit"
                                                                    class="btn btn-primary">Reemplazar</button>
                                                            </form>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                        </li>
                                        @endforeach
                                    </ul>
                                </div>
                            </div>
                        </div>
                        @endforeach
                    </div>
                </div>
            </div>
        </div>
    </div>
    @endforeach
</div>
@endsection